@@ -6,8 +6,6 @@ from flask.views import MethodView
 from openapi_core.contrib.flask.decorators import FlaskOpenAPIViewDecorator
 from openapi_core.contrib.flask.handlers import FlaskOpenAPIErrorsHandler
 from openapi_core.spec import Spec
-from openapi_core.validation.request import openapi_request_validator
-from openapi_core.validation.response import openapi_response_validator
 
 
 class FlaskOpenAPIView(MethodView):
@@ -22,8 +20,6 @@ class FlaskOpenAPIView(MethodView):
     def dispatch_request(self, *args: Any, **kwargs: Any) -> Any:
         decorator = FlaskOpenAPIViewDecorator(
             self.spec,
-            request_validator=openapi_request_validator,
-            response_validator=openapi_response_validator,
             openapi_errors_handler=self.openapi_errors_handler,
         )
         return decorator(super().dispatch_request)(*args, **kwargs)
